@@ -18,4 +18,23 @@ def convert_array_to_img(numpy_array:np.ndarray, serie_object:Series) -> sitk.Im
                                     0.0, 0.0, 1.0) )
         sitk_img.SetOrigin( instance_array[0].get_image_position())
         sitk_img.SetSpacing( (original_pixel_spacing[0], original_pixel_spacing[1], serie_object.get_z_spacing()) )
-        return sitk_img
\ No newline at end of file
+        return sitk_img
+
+class DictSitk2Numpy(object):
+    """
+    Convert a dictionnary of SimpleITK image into Numpy ndarray
+    """
+    def __init__(self, keys:tuple):
+        """constructor
+
+        Args:
+            keys (tuple): [tuple with key of sitk Image]
+        """
+        self.keys = keys
+
+    def __call__(self, img_dict):
+        
+        for key in self.keys:
+            img_dict[key] = sitk.GetArrayFromImage(img_dict.pop(key))
+        
+        return img_dict
\ No newline at end of file
